
function m14,redshift,sfr,mstellar,lambda_obs=lambda_obs,nu_obs=nu_obs,snu_obs=snu_obs

;; This function returns the dust temperature of a galaxy from its
;; redshift, SFR and stellar mass. These estimates are based on the
;; results of Magnelli et al. (2014; Eq. 5). If asked, the routine
;; will also predict the observed monochromatic fluxes of the galaxy.
;; These monochromatic fluxes correspond to those of a DH SED template
;; with the appropriate dust temperature (see Table A.1 of Magnelli et
;; al. 2014 for the DH template-Tdust pairing) and the appropriate
;; normalization. For the normalisation, we assume
;; SFR=10^-10*Lir[8-1000um], for a Chabrier IMF.   
;;
;; WARNING :: Dust temperatures and fluxes predictions are only
;; valid and provide in the redshift, stellar mass, SSFR and
;; wavelength ranges probed in Magnelli et al. (2014), i.e., 0<z<2.5,
;; Mstar>10^10 Msun, 10^-11<SSFR[yr-1]<10^-7 and 30um<lambda_rest<2mm 
;;
;;
;; If this routine was useful for your research, please cite Magnelli
;; et al. (2014)
;;
;;
;; If you have any question please contact B. Magnelli at :
;; magnelli@astro.uni-bonn.de 
;;
;;
;; ####################
;; INPUTS
;; ####################
;;   - redshift    : scalar containing the redshift of the galaxy
;;   - SFR         : scalar containing the SFR of the galaxy 
;;                   [units : Msun yr-1]
;;   - mstellar    : scalar containing the stellar mass of the galaxy 
;;                   [units : Msun]
;;
;;
;; ####################
;; KEYWORDS :
;; ####################
;;
;;   - lambda_obs  : Set this keyword to the wavelengths [scalar or
;;     vector] at which predictions of the observed monochromatic
;;     fluxes should be done. These are the observed wavelengths and
;;     NOT the rest-frame wavelengths. If lambda_obs is not specified,
;;     the monochromatic fluxes predictions are provided for the full
;;     wavelength range probed in Magnelli et al. (2014), i.e., 30um <
;;     lambda_rest < 2mm [units : micron] 
;;
;;   - nu_obs      : Set this keyword to the frequencies [scalar or
;;     vector] at which predictions of the observed monochromatic
;;     observed fluxes should be done. These are the observed
;;     frequencies and NOT the rest-frame frequencies. If nu_obs is
;;     not specified, the monochromatic fluxes predictions are
;;     provided for the full frequencies range probed in Magnelli et 
;;     al. (2014), i.e., 30um < lambda_rest < 2m. If lambda_obs is
;;     already specified, nu_obs is ignored [units : Hz]
;;
;;   - Snu_obs     : Set this keyword to a named variable that will
;;     contain the observed monochromatic fluxes predictions at
;;     lambda_obs or nu_obs [units : mJy] 
;;
;;
;; ####################
;; EXAMPLES : 
;; ####################
;;   1) to get the dust temperature of a galaxy at z = 1 and with
;;   SFR=10 Msun yr-1 and mstellar= 5.*10^10 MSun :
;;     IDL> print,m14(1.,10.,5.d10)
;;             26.759746
;;
;;   2) to get the dust temperature and the flux at lambda_obs=500um 
;;   of a galaxy at z = 1 and with SFR=10 Msun yr-1 and 
;;   mstellar= 5.*10^10 MSun :
;;     IDL> print,m14(1.,10.,5.d10,lambda_obs=500.,snu_obs=snu_obs)
;;             26.759746
;;     IDL> print,snu_obs
;;             1.6207123
;;
;;   3) to get the dust temperature and the flux over a broad range
;;   of far-infrared wavelengths of a galaxy at z = 1 and with
;;   SFR = 10 Msun yr-1 and mstellar = 5.*10^10 Msun :
;;     IDL> lambda_obs=60.+findgen(500)
;;     IDL> print,m14(1.,10.,5.d10,lambda_obs=lambda_obs,snu_obs=snu_obs)
;;             26.759746
;;     IDL> plot,lambda_obs,snu_obs,/xtype,/ytype
;;
;;   4) to get the dust temperature and the full FIR SED 
;;   of a galaxy at z = 1 and with SFR=10 Msun yr-1 and 
;;   mstellar= 5.*10^10 MSun :
;;     IDL> print,m14(1.,10.,5.d10,lambda_obs=lambda_obs,snu_obs=snu_obs)
;;             26.759746
;;     IDL> plot,lambda_obs,snu_obs,/xtype,/ytype
;;
;;
;; ####################
;; IMPORTANT NOTES : 
;; ####################
;;  * Dust temperature and flux predictions are only valid and
;;  provided in the redshift, stellar mass, SSFR and wavelength ranges
;;  probed in Magnelli et al. (2014), i.e., from 0<z<2.5, Mstar>10^10
;;  Msun, 10^-11 <SSFR[yr-1]< 10^-7 and 30um<lambda_rest<2mm 
;;  
;;  * This function makes use of LUMDIST.pro from the astron IDL
;;  library
;;
;;  * We use a cosmology with H0 = 71 km s−1 Mpc−1,
;;  Omega_lambda=0.73 and Omega_matter=0.27; These values can be
;;  changed at line 126
;-



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Verification of the input parameters ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

if (N_params() LT 3 ) then begin
    print,'SYNTAX ERROR - resuts=m14(redshift,SFR,M_star,[lambda_obs=lambda_obs,nu_obs=nu_obs,snu_obs=snu_obs])'
    return,-99.
endif


;;;;;; Luminosity distance ;;;;;;

distance=lumdist(redshift,H0=71.,omega=0.27,lambda0=0.73,/silent)

;; Restore the DH template library and the corresponding Lir and
;; Tdust grids

restore,'library_dh_magnelli.save'
ssfr=sfr/mstellar

if ssfr lt 10^(-11.) or ssfr gt 10^(-7.) then begin
   print,'The SSFR of your source is not in the SSFR range probed in Magnelli et al. (2014).'
   print,'We cannot predict the dust temperature of this source, sorry !'
   return,-99.
endif

if redshift lt 0. or redshift gt 2.5 then begin
   print,'The redshift of your source is not in the redshift range probed in Magnelli et al. (2014).'
   print,'We cannot predict the dust temperature of this source, sorry !'
   return,-99.
endif

if mstellar lt 10.^10. then begin
   print,'The stellar mass of your source is not in the stellar mass range probed in Magnelli et al. (2014).'
   print,'We cannot predict the dust temperature of this source, sorry !'
   return,-99.
endif

if keyword_set(lambda_obs) then begin
   nu_obs=2.997d14/lambda_obs
   if min(lambda_obs/(1.+redshift)) lt 30. or max(lambda_obs/(1.+redshift)) gt 2000. then begin
      print,'One or more observed wavelengths are outside the wavelength range probed in Magnelli et al. (2014)'
      print,'No monochromatic flux predictions will be provided for this(these) wavelengths'
   endif
endif

if keyword_set(nu_obs) and NOT(keyword_set(lambda_obs)) then begin
   lambda_obs=2.997d14/nu_obs
   if min(lambda_obs/(1.+redshift)) lt 30. or max(lambda_obs/(1.+redshift)) gt 2000. then begin
      print,'One or more observed wavelengths are outside the wavelength range probed in Magnelli et al. (2014)'
      print,'No monochromatic observed flux predictions will be provided for this(these) wavelengths'
   endif
endif

if NOT(keyword_set(lambda_obs)) and NOT(keyword_set(nu_obs)) then begin
   use=where(lambda ge 30. and lambda le 2000.)
   lambda_obs=lambda(use)*(1.+redshift)
endif


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



;;; Dust temperature prediction, Eq. 5 of Magnelli et al. (2014) 

tdust_obs=98.*(1. + redshift)^(-0.065)+6.9*alog10(ssfr)


;;; DH template corresponding to this dust temperature prediction
 
tt=min(abs(tdust_dh-tdust_obs),use_dh)


;; Normalization of the DH template

Lir_galaxy=10.^(10.)*SFR  ;;--->in Lsun
nu=2.997d14/lambda
lnuinlsun_rest=reform(nulnuinlsun(use_dh(0),*))/nu/templir(use_dh(0))*lir_galaxy  ;; ---> in Lsun Hz-1


;;; rest frame ----> observed frame 

lambda_obs_tot=lambda*(1.+redshift)  ;; ---> in micron
snu_obs_tot=(1d0+redshift)*lnuinlsun_rest/(4d0*!dpi*(distance*3.0856d24)^2.)*3.845d33/1.d-23*1.d3 ;; ---> en mJy


;;; Fluxes predictions at the requested wavelengths/frequencies

snu_obs=dblarr(N_elements(lambda_obs))-99.
use=where(lambda_obs/(1.+redshift) ge 30. and lambda_obs/(1.+redshift) le 2000.)

if use(0) ne -1 then begin
   snu_obs(use) = 10^(INTERPOL( alog10(snu_obs_tot), alog10(lambda_obs_tot), alog10(lambda_obs(use))))
endif

to_return=tdust_obs

return,to_return

end
